aboutsummaryrefslogtreecommitdiff
path: root/include/sysemu/dump-arch.h
diff options
context:
space:
mode:
authorAndrew Jones <drjones@redhat.com>2016-01-11 20:56:20 +0100
committerPeter Maydell <peter.maydell@linaro.org>2016-01-15 14:40:25 +0000
commit8161befdd15ddc5a8bb9e807ff1ac5907c594688 (patch)
treea2357c43d9deded78f16a3a5051918fd345a41f2 /include/sysemu/dump-arch.h
parentb09afd58e4cb61a854c34040a12962e5b6f05ca5 (diff)
downloadqemu-8161befdd15ddc5a8bb9e807ff1ac5907c594688.zip
qemu-8161befdd15ddc5a8bb9e807ff1ac5907c594688.tar.gz
qemu-8161befdd15ddc5a8bb9e807ff1ac5907c594688.tar.bz2
dump: allow target to set the page size
This is necessary for targets that don't have TARGET_PAGE_SIZE == real-target-page-size. The target should set the page size to the correct one, if known, or, if not known, to the maximum page size it supports. (No functional change.) Signed-off-by: Andrew Jones <drjones@redhat.com> Reviewed-by: Peter Maydell <peter.maydell@linaro.org> Message-id: 1452542185-10914-4-git-send-email-drjones@redhat.com Signed-off-by: Peter Maydell <peter.maydell@linaro.org>
Diffstat (limited to 'include/sysemu/dump-arch.h')
-rw-r--r--include/sysemu/dump-arch.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/include/sysemu/dump-arch.h b/include/sysemu/dump-arch.h
index 9c95ced..4335839 100644
--- a/include/sysemu/dump-arch.h
+++ b/include/sysemu/dump-arch.h
@@ -15,9 +15,11 @@
#define DUMP_ARCH_H
typedef struct ArchDumpInfo {
- int d_machine; /* Architecture */
- int d_endian; /* ELFDATA2LSB or ELFDATA2MSB */
- int d_class; /* ELFCLASS32 or ELFCLASS64 */
+ int d_machine; /* Architecture */
+ int d_endian; /* ELFDATA2LSB or ELFDATA2MSB */
+ int d_class; /* ELFCLASS32 or ELFCLASS64 */
+ uint32_t page_size; /* The target's page size. If it's variable and
+ * unknown, then this should be the maximum. */
} ArchDumpInfo;
struct GuestPhysBlockList; /* memory_mapping.h */